[Libreoffice-commits] core.git: filter/source

Luboš Luňák l.lunak at collabora.com
Sun Apr 13 14:09:32 PDT 2014


 filter/source/msfilter/msdffimp.cxx |    5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

New commits:
commit af51f3fb5aee469423b154958ccb3fe61284122f
Author: Luboš Luňák <l.lunak at collabora.com>
Date:   Sun Apr 13 23:06:58 2014 +0200

    handle .doc cropping also inside groups (fdo#38411)
    
    Writer does handle cropping on its own, but only for "toplevel" images,
    not for those inside groups, so there still use the generic code.
    
    Change-Id: I805a4cbd2d4cea7008e0322688ccd7f35a6d4a2c

diff --git a/filter/source/msfilter/msdffimp.cxx b/filter/source/msfilter/msdffimp.cxx
index ff8a9b3..8d6457b 100644
--- a/filter/source/msfilter/msdffimp.cxx
+++ b/filter/source/msfilter/msdffimp.cxx
@@ -3752,8 +3752,9 @@ SdrObject* SvxMSDffManager::ImportGraphic( SvStream& rSt, SfxItemSet& rSet, cons
         }
         if ( bGrfRead )
         {
-            // the writer is doing it's own cropping, so this part affects only impress and calc
-            if ( GetSvxMSDffSettings() & SVXMSDFF_SETTINGS_CROP_BITMAPS )
+            // the writer is doing its own cropping, so this part affects only impress and calc,
+            // unless we're inside a group, in which case writer doesn't crop either
+            if (( GetSvxMSDffSettings() & SVXMSDFF_SETTINGS_CROP_BITMAPS ) || rObjData.nCalledByGroup != 0 )
                 lcl_ApplyCropping( *this, ( rObjData.nSpFlags & SP_FOLESHAPE ) == 0 ? &rSet : NULL, aGraf );
 
             if ( IsProperty( DFF_Prop_pictureTransparent ) )


More information about the Libreoffice-commits mailing list